# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/ledger/transaction/v1/transaction_action.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/ledger/transaction/v1/transaction_action.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8meshtrade/ledger/transaction/v1/transaction_action.proto\x12\x1fmeshtrade.ledger.transaction.v1*\xf8\x01\n\x11TransactionAction\x12\"\n\x1eTRANSACTION_ACTION_UNSPECIFIED\x10\x00\x12!\n\x1dTRANSACTION_ACTION_DO_NOTHING\x10\x01\x12\x1c\n\x18TRANSACTION_ACTION_BUILD\x10\x02\x12\x1d\n\x19TRANSACTION_ACTION_COMMIT\x10\x03\x12\x1b\n\x17TRANSACTION_ACTION_SIGN\x10\x04\x12#\n\x1fTRANSACTION_ACTION_MARK_PENDING\x10\x05\x12\x1d\n\x19TRANSACTION_ACTION_SUBMIT\x10\x06\x42\x41Z?github.com/meshtrade/api/go/ledger/transaction/v1;transactionv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.ledger.transaction.v1.transaction_action_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/meshtrade/api/go/ledger/transaction/v1;transactionv1'
  _globals['_TRANSACTIONACTION']._serialized_start=94
  _globals['_TRANSACTIONACTION']._serialized_end=342
# @@protoc_insertion_point(module_scope)
