# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/wallet/account/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/wallet/account/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.option.v1 import auth_pb2 as meshtrade_dot_option_dot_v1_dot_auth__pb2
from meshtrade.option.v1 import service_type_pb2 as meshtrade_dot_option_dot_v1_dot_service__type__pb2
from meshtrade.type.v1 import ledger_pb2 as meshtrade_dot_type_dot_v1_dot_ledger__pb2
from meshtrade.wallet.account.v1 import account_pb2 as meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)meshtrade/wallet/account/v1/service.proto\x12\x1bmeshtrade.wallet.account.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1emeshtrade/option/v1/auth.proto\x1a&meshtrade/option/v1/service_type.proto\x1a\x1emeshtrade/type/v1/ledger.proto\x1a)meshtrade/wallet/account/v1/account.proto\"\x8b\x01\n\x14\x43reateAccountRequest\x12\"\n\x05label\x18\x01 \x01(\tB\x0c\xbaH\tr\x04\x10\x03\x18\x32\xc8\x01\x01R\x05label\x12;\n\x06ledger\x18\x02 \x01(\x0e\x32\x19.meshtrade.type.v1.LedgerB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x06ledger\x12\x12\n\x04open\x18\x03 \x01(\x08R\x04open\"8\n\x11GetAccountRequest\x12#\n\x06number\x18\x01 \x01(\tB\x0b\xbaH\x08r\x03\x98\x01\x07\xc8\x01\x01R\x06number\"\x15\n\x13ListAccountsRequest\"X\n\x14ListAccountsResponse\x12@\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x08\x61\x63\x63ounts\";\n\x15SearchAccountsRequest\x12\"\n\x05label\x18\x01 \x01(\tB\x0c\xbaH\tr\x04\x10\x03\x18\x32\xc8\x01\x00R\x05label\"Z\n\x16SearchAccountsResponse\x12@\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x08\x61\x63\x63ounts2\x87\x04\n\x0e\x41\x63\x63ountService\x12u\n\rCreateAccount\x12\x31.meshtrade.wallet.account.v1.CreateAccountRequest\x1a$.meshtrade.wallet.account.v1.Account\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x01\x12p\n\nGetAccount\x12..meshtrade.wallet.account.v1.GetAccountRequest\x1a$.meshtrade.wallet.account.v1.Account\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x01\x02\x12\x81\x01\n\x0cListAccounts\x12\x30.meshtrade.wallet.account.v1.ListAccountsRequest\x1a\x31.meshtrade.wallet.account.v1.ListAccountsResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x01\x02\x12\x87\x01\n\x0eSearchAccounts\x12\x32.meshtrade.wallet.account.v1.SearchAccountsRequest\x1a\x33.meshtrade.wallet.account.v1.SearchAccountsResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x01\x02\x42\x41Z7github.com/meshtrade/api/go/wallet/account/v1;accountv1\x9a\xb5\x18\x04\n\x02\x01\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.wallet.account.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/meshtrade/api/go/wallet/account/v1;accountv1\232\265\030\004\n\002\001\002'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['label']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['label']._serialized_options = b'\272H\tr\004\020\003\0302\310\001\001'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['ledger']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['ledger']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_GETACCOUNTREQUEST'].fields_by_name['number']._loaded_options = None
  _globals['_GETACCOUNTREQUEST'].fields_by_name['number']._serialized_options = b'\272H\010r\003\230\001\007\310\001\001'
  _globals['_SEARCHACCOUNTSREQUEST'].fields_by_name['label']._loaded_options = None
  _globals['_SEARCHACCOUNTSREQUEST'].fields_by_name['label']._serialized_options = b'\272H\tr\004\020\003\0302\310\001\000'
  _globals['_ACCOUNTSERVICE'].methods_by_name['CreateAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['CreateAccount']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\001'
  _globals['_ACCOUNTSERVICE'].methods_by_name['GetAccount']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['GetAccount']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\001\002'
  _globals['_ACCOUNTSERVICE'].methods_by_name['ListAccounts']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['ListAccounts']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\001\002'
  _globals['_ACCOUNTSERVICE'].methods_by_name['SearchAccounts']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['SearchAccounts']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\001\002'
  _globals['_CREATEACCOUNTREQUEST']._serialized_start=251
  _globals['_CREATEACCOUNTREQUEST']._serialized_end=390
  _globals['_GETACCOUNTREQUEST']._serialized_start=392
  _globals['_GETACCOUNTREQUEST']._serialized_end=448
  _globals['_LISTACCOUNTSREQUEST']._serialized_start=450
  _globals['_LISTACCOUNTSREQUEST']._serialized_end=471
  _globals['_LISTACCOUNTSRESPONSE']._serialized_start=473
  _globals['_LISTACCOUNTSRESPONSE']._serialized_end=561
  _globals['_SEARCHACCOUNTSREQUEST']._serialized_start=563
  _globals['_SEARCHACCOUNTSREQUEST']._serialized_end=622
  _globals['_SEARCHACCOUNTSRESPONSE']._serialized_start=624
  _globals['_SEARCHACCOUNTSRESPONSE']._serialized_end=714
  _globals['_ACCOUNTSERVICE']._serialized_start=717
  _globals['_ACCOUNTSERVICE']._serialized_end=1236
# @@protoc_insertion_point(module_scope)
