# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/company_representative.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/company_representative.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from meshtrade.compliance.client.v1 import company_representative_role_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_company__representative__role__pb2
from meshtrade.compliance.client.v1 import natural_person_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_natural__person__pb2
from meshtrade.type.v1 import contact_details_pb2 as meshtrade_dot_type_dot_v1_dot_contact__details__pb2
from meshtrade.type.v1 import decimal_pb2 as meshtrade_dot_type_dot_v1_dot_decimal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;meshtrade/compliance/client/v1/company_representative.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x16google/type/date.proto\x1a@meshtrade/compliance/client/v1/company_representative_role.proto\x1a\x33meshtrade/compliance/client/v1/natural_person.proto\x1a\'meshtrade/type/v1/contact_details.proto\x1a\x1fmeshtrade/type/v1/decimal.proto\"\xcf\x03\n\x15\x43ompanyRepresentative\x12T\n\x0enatural_person\x18\x01 \x01(\x0b\x32-.meshtrade.compliance.client.v1.NaturalPersonR\rnaturalPerson\x12M\n\x04role\x18\x02 \x01(\x0e\x32\x39.meshtrade.compliance.client.v1.CompanyRepresentativeRoleR\x04role\x12\x1a\n\x08position\x18\x03 \x01(\tR\x08position\x12M\n\x14ownership_percentage\x18\x04 \x01(\x0b\x32\x1a.meshtrade.type.v1.DecimalR\x13ownershipPercentage\x12\x63\n\x1cprofessional_contact_details\x18\x05 \x01(\x0b\x32!.meshtrade.type.v1.ContactDetailsR\x1aprofessionalContactDetails\x12\x41\n\x13\x64\x61te_of_appointment\x18\x06 \x01(\x0b\x32\x11.google.type.DateR\x11\x64\x61teOfAppointmentB;Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.company_representative_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1'
  _globals['_COMPANYREPRESENTATIVE']._serialized_start=313
  _globals['_COMPANYREPRESENTATIVE']._serialized_end=776
# @@protoc_insertion_point(module_scope)
