# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/company_representative_role.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/company_representative_role.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@meshtrade/compliance/client/v1/company_representative_role.proto\x12\x1emeshtrade.compliance.client.v1*\xc4\x03\n\x19\x43ompanyRepresentativeRole\x12+\n\'COMPANY_REPRESENTATIVE_ROLE_UNSPECIFIED\x10\x00\x12\x39\n5COMPANY_REPRESENTATIVE_ROLE_ULTIMATE_BENEFICIAL_OWNER\x10\x01\x12+\n\'COMPANY_REPRESENTATIVE_ROLE_SHAREHOLDER\x10\x02\x12/\n+COMPANY_REPRESENTATIVE_ROLE_SOLE_PROPRIETOR\x10\x03\x12\'\n#COMPANY_REPRESENTATIVE_ROLE_PARTNER\x10\x04\x12(\n$COMPANY_REPRESENTATIVE_ROLE_DIRECTOR\x10\x05\x12\'\n#COMPANY_REPRESENTATIVE_ROLE_MANAGER\x10\x06\x12\x34\n0COMPANY_REPRESENTATIVE_ROLE_AUTHORIZED_SIGNATORY\x10\x07\x12/\n+COMPANY_REPRESENTATIVE_ROLE_PRIMARY_CONTACT\x10\x08\x42;Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.company_representative_role_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1'
  _globals['_COMPANYREPRESENTATIVEROLE']._serialized_start=101
  _globals['_COMPANYREPRESENTATIVEROLE']._serialized_end=553
# @@protoc_insertion_point(module_scope)
