# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/type/v1/address.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/type/v1/address.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmeshtrade/type/v1/address.proto\x12\x11meshtrade.type.v1\"\xba\x01\n\x07\x41\x64\x64ress\x12#\n\raddress_lines\x18\x01 \x03(\tR\x0c\x61\x64\x64ressLines\x12\x16\n\x06suburb\x18\x02 \x01(\tR\x06suburb\x12\x12\n\x04\x63ity\x18\x03 \x01(\tR\x04\x63ity\x12\x1a\n\x08province\x18\x04 \x01(\tR\x08province\x12!\n\x0c\x63ountry_code\x18\x05 \x01(\tR\x0b\x63ountryCode\x12\x1f\n\x0bpostal_code\x18\x06 \x01(\tR\npostalCodeB,Z*github.com/meshtrade/api/go/type/v1;typev1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.type.v1.address_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*github.com/meshtrade/api/go/type/v1;typev1'
  _globals['_ADDRESS']._serialized_start=55
  _globals['_ADDRESS']._serialized_end=241
# @@protoc_insertion_point(module_scope)
