# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/source_of_income_and_wealth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/source_of_income_and_wealth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@meshtrade/compliance/client/v1/source_of_income_and_wealth.proto\x12\x1emeshtrade.compliance.client.v1*\x99\t\n\x17SourceOfIncomeAndWealth\x12+\n\'SOURCE_OF_INCOME_AND_WEALTH_UNSPECIFIED\x10\x00\x12*\n&SOURCE_OF_INCOME_AND_WEALTH_ALLOWANCES\x10\x01\x12\'\n#SOURCE_OF_INCOME_AND_WEALTH_BURSARY\x10\x02\x12+\n\'SOURCE_OF_INCOME_AND_WEALTH_COURT_ORDER\x10\x03\x12:\n6SOURCE_OF_INCOME_AND_WEALTH_LOAN_FINANCIAL_INSTITUTION\x10\x04\x12*\n&SOURCE_OF_INCOME_AND_WEALTH_LOAN_OTHER\x10\x05\x12+\n\'SOURCE_OF_INCOME_AND_WEALTH_MAINTENANCE\x10\x06\x12\x34\n0SOURCE_OF_INCOME_AND_WEALTH_MATURING_INVESTMENTS\x10\x07\x12\'\n#SOURCE_OF_INCOME_AND_WEALTH_PENSION\x10\x08\x12-\n)SOURCE_OF_INCOME_AND_WEALTH_RENTAL_INCOME\x10\t\x12/\n+SOURCE_OF_INCOME_AND_WEALTH_COMPANY_PROFITS\x10\n\x12,\n(SOURCE_OF_INCOME_AND_WEALTH_COMPANY_SALE\x10\x0b\x12/\n+SOURCE_OF_INCOME_AND_WEALTH_DECEASED_ESTATE\x10\x0c\x12\x32\n.SOURCE_OF_INCOME_AND_WEALTH_DIVORCE_SETTLEMENT\x10\r\x12\x30\n,SOURCE_OF_INCOME_AND_WEALTH_GIFT_OR_DONATION\x10\x0e\x12\x36\n2SOURCE_OF_INCOME_AND_WEALTH_INCOME_FROM_EMPLOYMENT\x10\x0f\x12?\n;SOURCE_OF_INCOME_AND_WEALTH_INCOME_FROM_PREVIOUS_EMPLOYMENT\x10\x10\x12+\n\'SOURCE_OF_INCOME_AND_WEALTH_INHERITANCE\x10\x11\x12<\n8SOURCE_OF_INCOME_AND_WEALTH_LOTTERY_WINNINGS_OR_GAMBLING\x10\x12\x12-\n)SOURCE_OF_INCOME_AND_WEALTH_SALE_OF_ASSET\x10\x13\x12.\n*SOURCE_OF_INCOME_AND_WEALTH_SALE_OF_SHARES\x10\x14\x12>\n:SOURCE_OF_INCOME_AND_WEALTH_SAVINGS_INVESTMENT_OR_DIVIDEND\x10\x15\x12\x33\n/SOURCE_OF_INCOME_AND_WEALTH_TRUST_DISTRIBUTIONS\x10\x16\x42;Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.source_of_income_and_wealth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1'
  _globals['_SOURCEOFINCOMEANDWEALTH']._serialized_start=101
  _globals['_SOURCEOFINCOMEANDWEALTH']._serialized_end=1278
# @@protoc_insertion_point(module_scope)
